/**
 * External dependencies
 */
import styled from "@emotion/styled";

/**
 * WordPress dependencies
 */

// Page wrapper
export const PageStyled = styled.div`
  margin-top: 20px;

  .scrollbar {
    overflow: auto;

    &::-webkit-scrollbar {
      width: 10px;
      height: 10px;
    }

    &::-webkit-scrollbar-thumb,
    &::-webkit-scrollbar-track {
      border-radius: 6px;
    }

    &::-webkit-scrollbar-thumb {
      background-color: #b9b9b9;
    }

    &::-webkit-scrollbar-track {
      background-color: #e2e2e2;
    }
  }

  .template-header {
    display: flex;
    flex-wrap: wrap;
    align-items: center;
    padding: 6px 8px;
    margin-bottom: 0.75rem;
    background-color: #fff;
    border: 1px solid #ddd;

    .sort-box {
      width: 120px;
      background-color: #f0f0f0;
    }

    .components-dropdown {
      width: 100%;
    }

    .components-button.has-icon {
      width: 100%;
      padding: 8px;
    }

    .keywords-filter {
      align-self: center;
      order: 2;
      width: 100%;
      margin-top: 0.5rem;

      &__label {
        display: flex;

        svg {
          margin-right: 5px;
        }
      }
    }

    &__actions {
      display: flex;
      margin-left: auto;

      button {
        padding: 0;
      }
    }

    @media (min-width: 1280px) {
      // $break-wide
      .sort-box {
        margin-right: calc(1rem - 5px);
      }

      .keywords-filter {
        order: 0;
        margin-top: 0;
        width: calc(100% - 120px - 240px - 72px - 2rem);
      }
    }
  }

  .template-list-wrapper {
    display: flex;
    flex-direction: column;
    height: 100%;
    max-height: 100%;
    margin-bottom: 0;
    overflow: auto;

    .pagination-links {
      padding-top: 0.5rem;
      margin: auto 0 0;
    }
  }

  .template-list-not-found {
    padding: 0.5rem;
    background-color: #fff;
    border: 1px solid #ddd;
  }

  .template-modal__legend {
    margin: auto 0 1rem;
    font-size: 1.2em;

    p {
      margin: 0;
    }
  }

  &.is-locked {
    pointer-events: none;
  }

  .block-library-notices {
    .block-library-notice {
      margin: 0 0 10px 0;
      padding-right: 10px;
    }

    .components-notice__content {
      display: flex;
      flex-wrap: wrap;
    }

    .notice-message {
      margin-right: 12px;
    }

    .components-notice__actions {
      gap: 12px;

      > .components-notice__action {
        margin-left: 0 !important;
      }
    }
  }

  .template-item {
    .components-spinner {
      position: absolute;
      margin: 10px;
    }
  }

  .item-notices {
    position: absolute;
    bottom: 0;
    left: 0;

    .item-notice {
      width: 100%;
      padding: 4px 10px;
      margin: 0;
    }
  }

  .template-item__preview-wrapper {
    display: flex;
    flex-grow: 1;
  }

  .template-item__footer {
    /* min-height: 90px; */
    overflow: auto;
    padding: 12px !important;
  }

  // Title
  .template-item__title-details {
    flex-wrap: wrap;
    margin-bottom: 4px !important;

    > * {
      flex-basis: 100%;
    }

    .template-item__title {
      max-width: 100% !important;
      margin-bottom: 4px !important;
      line-height: 1.4;
    }
  }

  // Actions
  .template-item__actions {
    gap: 0.25rem !important;
    margin-bottom: 4px;

    > *:not(button) {
      flex-basis: 100%;
    }

    ul {
      margin: 0;

      li {
        margin: 0;
      }
    }

    .template-item__description {
      margin: 0 0 0.25rem;
    }
  }

  .template-item__links {
    display: flex;
    flex-wrap: wrap;
    gap: 0.5rem;
    width: 100%;
  }
`;
