/**
 * External dependencies
 */

/**
 * WordPress dependencies
 */
import { createReduxStore, register, combineReducers } from "@wordpress/data";
import { controls } from "@wordpress/data-controls";

/**
 * Internal dependencies
 */
import {
  blockLibraryActions,
  blockLibrarySelectors,
  blockLibraryResolvers,
  blockLibraryReducer,
} from "./blocks";

import {
  variationLibraryActions,
  variationLibrarySelectors,
  variationLibraryResolvers,
  variationLibraryReducer,
} from "./variations";

/**
 * Constants
 */
const storeName = "boldblocks/block-library";

/**
 * Register store
 */
const store = createReduxStore(storeName, {
  selectors: {
    ...blockLibrarySelectors,
    ...variationLibrarySelectors,
  },
  actions: {
    ...blockLibraryActions,
    ...variationLibraryActions,
  },
  controls,
  reducer: combineReducers({
    blockLibrary: blockLibraryReducer,
    variationLibrary: variationLibraryReducer,
  }),
  resolvers: {
    ...blockLibraryResolvers,
    ...variationLibraryResolvers,
  },
});
register(store);

export { storeName as store };
