/**
 * External dependencies
 */

/**
 * WordPress dependencies
 */
import { __ } from "@wordpress/i18n";
import {
  Button,
  Spinner,
  BaseControl,
  __experimentalConfirmDialog as ConfirmDialog,
} from "@wordpress/components";
import { addQueryArgs } from "@wordpress/url";
import { useState } from "@wordpress/element";

/**
 * Internal dependencies
 */
import { BlockInfoStyled } from "./styles";

const BlockAdditionalInfo = ({
  blockInfo,
  canEdit,
  canSyncContent,
  onResetContent,
  onPushContent,
  isUpdating,
}) => {
  const {
    id,
    name,
    parentName,
    childName,
    templateLock,
    layoutType,
    template,
  } = blockInfo;

  const [isOpenPullingConfirm, setIsOpenPullingConfirm] = useState(false);
  const [isOpenPushingConfirm, setIsOpenPushingConfirm] = useState(false);

  return (
    <BlockInfoStyled className="block-info">
      <div className="block-info__item">
        <div className="block-info__label">
          {__("Name: ", "content-blocks-builder")}
        </div>
        <div className="block-info__value">
          <code>{name}</code>
        </div>
      </div>
      {childName && (
        <div className="block-info__item">
          <div className="block-info__label">
            {__("Child block: ", "content-blocks-builder")}
          </div>
          <div className="block-info__value">
            <code>{childName}</code>
          </div>
        </div>
      )}
      {parentName && (
        <div className="block-info__item">
          <div className="block-info__label">
            {__("Parent block: ", "content-blocks-builder")}
          </div>
          <div className="block-info__value">
            <code>{parentName}</code>
          </div>
        </div>
      )}
      <div className="block-info__item">
        <div className="block-info__label">
          {__("Layout: ", "content-blocks-builder")}
        </div>
        <div className="block-info__value">
          <code>{layoutType}</code>
        </div>
      </div>
      <div className="block-info__item">
        <div className="block-info__label">
          {__("Template lock: ", "content-blocks-builder")}
        </div>
        <div className="block-info__value">
          <code>{templateLock ? templateLock : "None"}</code>
        </div>
      </div>
      {(canEdit || canSyncContent) && (
        <div className="block-info__actions">
          <ConfirmDialog
            isOpen={isOpenPullingConfirm}
            onConfirm={() => {
              onResetContent(template);
              setIsOpenPullingConfirm(false);
            }}
            onCancel={() => {
              setIsOpenPullingConfirm(false);
            }}
          >
            {__(
              "Are you sure to replace the block content with the default block content?",
              "content-blocks-builder"
            )}
          </ConfirmDialog>
          <ConfirmDialog
            isOpen={isOpenPushingConfirm}
            onConfirm={() => {
              onPushContent(id);
              setIsOpenPushingConfirm(false);
            }}
            onCancel={() => {
              setIsOpenPushingConfirm(false);
            }}
          >
            {__(
              "Are you sure to replace the default block content with this block content?",
              "content-blocks-builder"
            )}
          </ConfirmDialog>
          <div className="block-info__actions__buttons">
            {canEdit && (
              <Button
                variant="primary"
                size="small"
                target="_blank"
                href={addQueryArgs(`post.php?post=${id}&action=edit`)}
              >
                {__("Edit block", "content-blocks-builder")}
              </Button>
            )}
            {canSyncContent && (
              <>
                <Button
                  variant="primary"
                  size="small"
                  className="reset-content"
                  onClick={() => setIsOpenPullingConfirm(true)}
                >
                  {__("Reset content", "content-blocks-builder")}
                </Button>
                <Button
                  variant="primary"
                  size="small"
                  className="push-content"
                  disabled={isUpdating}
                  onClick={() => setIsOpenPushingConfirm(true)}
                >
                  {__("Push changes", "content-blocks-builder")}
                  {isUpdating && <Spinner />}
                </Button>
              </>
            )}
          </div>
          {canSyncContent && (
            <BaseControl
              help={
                <>
                  {__(
                    "Reset content will replace the current block content with the default block content.",
                    "content-blocks-builder"
                  )}
                  <br />
                  {__(
                    "Push changes will save the current block content as the default block content.",
                    "content-blocks-builder"
                  )}
                </>
              }
            />
          )}
        </div>
      )}
    </BlockInfoStyled>
  );
};

export default BlockAdditionalInfo;
