/**
 * External dependencies
 */
import { noop } from "lodash";

/**
 * WordPress dependencies
 */
import { __ } from "@wordpress/i18n";
import { useState } from "@wordpress/element";
import {
  TextControl,
  Button,
  Modal,
  Flex,
  FlexItem,
} from "@wordpress/components";

/**
 * Internal dependencies
 */

/**
 * Form for adding custom variation
 *
 * @param {BlockEditModalProps} props Component props.
 *
 * @return {WPComponent}.
 */
export default function BlockEditModal({
  modalTitle,
  title: initialTitle,
  titleHelp,
  setIsModalOpen,
  onSubmit = noop,
  onCancel = noop,
  className,
}) {
  const [title, setTitle] = useState(initialTitle);

  // Handle modal close event.
  const closeModal = () => {
    setIsModalOpen(false);
    setTitle("");
    onCancel();
  };

  return (
    <Modal
      title={modalTitle}
      closeLabel={__("Close", "content-blocks-builder")}
      onRequestClose={() => closeModal()}
      overlayClassName="reusable-blocks-menu-items__convert-modal"
      className={className}
    >
      <form
        onSubmit={(event) => {
          event.preventDefault();
          onSubmit(title);

          closeModal();
        }}
      >
        <TextControl
          label={__("Name", "content-blocks-builder")}
          value={title}
          onChange={setTitle}
          help={titleHelp}
          className="title-input"
        />
        <Flex
          className="reusable-blocks-menu-items__convert-modal-actions"
          justify="flex-end"
        >
          <FlexItem>
            <Button variant="secondary" onClick={() => closeModal()}>
              {__("Cancel", "content-blocks-builder")}
            </Button>
          </FlexItem>
          <FlexItem>
            <Button variant="primary" type="submit" disabled={!title}>
              {__("Save", "content-blocks-builder")}
            </Button>
          </FlexItem>
        </Flex>
      </form>
    </Modal>
  );
}
