/**
 * External dependencies
 */
import styled from "@emotion/styled";

/**
 * WordPress dependencies
 */
import { Modal } from "@wordpress/components";

// Modal wrapper
export const ModalStyled = styled(Modal)`
  .scrollbar {
    overflow: auto;

    &::-webkit-scrollbar {
      width: 10px;
      height: 10px;
    }

    &::-webkit-scrollbar-thumb,
    &::-webkit-scrollbar-track {
      border-radius: 6px;
    }

    &::-webkit-scrollbar-thumb {
      background-color: #b9b9b9;
    }

    &::-webkit-scrollbar-track {
      background-color: #e2e2e2;
    }
  }

  // Modal content
  .components-modal__content {
    display: flex;
    flex-direction: column;
    padding: 1rem;
    background-color: #f9f9f9;

    > div:not(.template-modal__legend, .template-header) {
      display: flex;
      flex-direction: column;
      max-height: 100%;
    }
  }

  .template-header {
    display: flex;
    flex-wrap: wrap;
    align-items: center;
    margin-bottom: 0.75rem;

    .search-box {
      flex-grow: 1;
      margin-right: 1rem;
      max-width: calc(100% - 120px - 72px - 1rem);

      @media (max-width: 599px) {
        max-width: calc(100% - 40px - 72px - 1rem);
      }

      > * {
        margin-bottom: 0;
      }
    }

    .sort-box {
      width: 120px;
      background-color: #f0f0f0;

      @media (max-width: 599px) {
        /* $break-medium: 600px */
        width: 40px;

        .text {
          display: none;
        }

        .components-button.has-icon.has-text svg {
          margin-right: 0;
        }
      }

      @media (max-width: 1279px) {
        align-self: flex-start;
      }

      .components-dropdown {
        width: 100%;
      }

      .components-button.has-icon {
        width: 100%;
        padding: 8px;
      }
    }

    .keywords-filter {
      order: 2;
      width: 100%;
      margin-top: 0.5rem;

      &__label {
        display: flex;

        svg {
          margin-right: 5px;
        }
      }
    }

    &__actions {
      display: flex;
      margin-left: auto;
      align-self: flex-start;

      button {
        padding: 0;
      }
    }

    @media (min-width: 1280px) {
      // $break-wide
      .search-box {
        width: 240px;
      }

      .sort-box {
        margin-right: calc(1rem - 5px);
      }

      .keywords-filter {
        order: 0;
        margin-top: 0;
        width: calc(100% - 120px - 240px - 72px - 2rem);
      }
    }
  }

  .template-list-wrapper {
    display: flex;
    flex-direction: column;
    flex: 1;
    height: 100%;
    margin-bottom: 0;
    overflow: auto;

    .pagination-links {
      padding-top: 0.5rem;
      margin: auto 0 0;
    }
  }

  .template-list-not-found {
    padding: 0.5rem;
    background-color: #fff;
    border: 1px solid #ddd;
  }

  .template-modal__legend {
    margin: auto 0 1rem;
    font-size: 1.2em;

    p {
      margin: 0;
    }
  }

  &.is-locked {
    pointer-events: none;
  }
`;

export const TemplateGridStyled = styled.div`
  display: grid;
  grid-template-columns: repeat(1, 1fr);
  gap: 1rem;

  @media (min-width: 782px) {
    // $break-medium
    grid-template-columns: repeat(2, 1fr);
  }

  @media (min-width: 1280px) {
    // $break-wide
    grid-template-columns: repeat(3, 1fr);
  }
`;

export const TemplateItemStyled = styled.div`
  position: relative;
  display: flex;
  flex-direction: column;
  overflow: hidden;
  background-color: #fff;
  border: 1px solid #ddd;
  transition: border-color 0.15s ease-in-out;

  .template-item__preview {
    position: relative;
    display: flex;
    flex-direction: column;
    justify-content: center;
    flex-grow: 1;
    min-height: 10rem;
    padding-top: 1.25rem;
    padding-bottom: 1.25rem;

    .template-item__thumbnail {
      max-height: 18rem;
      margin: 0 0.5rem;

      img {
        width: 100%;
      }
    }
  }

  &.is-ready {
    .template-item__preview {
      cursor: pointer;
    }

    &:hover {
      border-color: var(--wp-admin-theme-color, #007cba);
    }
  }

  &.is-inserting {
    position: relative;

    .template-item__preview {
      opacity: 0.6;
    }

    .components-spinner {
      position: absolute;
      top: calc(50% - 16px);
      left: calc(50% - 16px);
    }
  }

  .components-spinner {
    position: absolute;
    margin: 10px;
  }

  .item-notices {
    position: absolute;
    bottom: 0;
    left: 0;

    .item-notice {
      width: 100%;
      padding: 4px 10px;
      margin: 0;
    }

    .components-notice__actions {
      gap: 8px;

      > .components-notice__action {
        margin: 4px 0 0 !important;
      }
    }
  }

  .template-item__badges {
    position: absolute;
    top: 0.5rem;
    right: 0.5rem;

    > * {
      display: inline-block;
      padding: 3px 6px;
      color: #fff;
      background-color: var(--wp-admin-theme-color, #007cba);
      border-radius: 2px;

      + * {
        margin-left: 4px;
      }
    }
  }

  &.has-missing-blocks {
    .template-item__preview {
      padding: 1.25rem;
    }
  }

  .notice-missing-block,
  .notice-require-pro {
    position: absolute;
    bottom: 0;
    left: 0;
    width: 100%;
    margin-left: 0;
  }

  .template-item__footer {
    padding: calc(1rem - 0.2em) 1rem calc(1rem + 0.2em);
    background-color: #f0f0f0;
    border-top: 1px solid #ddd;

    > * {
      margin: 0 0 0.5rem;

      &:last-child {
        margin-bottom: 0;
      }
    }
  }

  .template-item__title-details {
    display: flex;

    .template-item__title {
      max-width: calc(100% - 80px);
      margin-bottom: 0;
      overflow: hidden;
    }

    .template-item__more {
      flex-basis: 80px;
      margin-left: auto;
      text-align: right;
    }
  }

  .template-item__title {
    margin-top: 0;
    font-size: 1rem;
    line-height: 1;
    white-space: nowrap;
    text-overflow: ellipsis;
  }

  .template-item__links {
    display: inline-flex;
    flex-wrap: wrap;
    gap: 0.5rem;
    width: 100%;

    li {
      margin-bottom: 0;
    }
  }

  .template-item__actions {
    display: flex;
    flex-wrap: wrap;
    gap: 0.5rem;
  }

  .template-item__messages {
    p {
      margin: 0;
    }
  }
`;
