/**
 * External dependencies
 */
import { isEmpty, pick } from "lodash";

/**
 * WordPress dependencies
 */
import { BlockControls, ButtonBlockAppender } from "@wordpress/block-editor";
import { ToolbarGroup } from "@wordpress/components";
import { addFilter } from "@wordpress/hooks";
import { hasBlockSupport } from "@wordpress/blocks";

/**
 * Internal dependencies
 */
import { getCoreFeatures, boldblocksHasSupport } from "../utils";

/**
 * Add a button on the parent block's toolbar to add child blocks
 */
addFilter(
  "boldblocks.edit.blockEditInner",
  `boldblocks/blockEditInner/addChildBlock`,
  (content, props) => {
    const layoutType = boldblocksHasSupport(props.name, "layoutType");
    if (!["carousel", "grid", "accordion", "vstack"].includes(layoutType)) {
      return content;
    }

    const { isSelected, clientId } = props;

    return (
      <>
        {content}
        {isSelected && (
          <BlockControls>
            <ToolbarGroup>
              <ButtonBlockAppender rootClientId={clientId} />
            </ToolbarGroup>
          </BlockControls>
        )}
      </>
    );
  }
);

/**
 * Force block support for core features on CBB blocks
 */
addFilter(
  "blockEditor.useSetting.before",
  "boldblocks/CBB/useSetting.before",
  (settingValue, settingName, clientId, blockName) => {
    if (!hasBlockSupport(blockName, "cbb")) {
      return settingValue;
    }

    // Force color attributes
    if (
      ["color.text", "color.background", "color.link"].includes(settingName)
    ) {
      return true;
    }

    if (
      [
        "spacing.padding",
        "spacing.margin",
        "spacing.blockGap",
        "dimensions.minHeight",
      ].includes(settingName)
    ) {
      const layoutType = boldblocksHasSupport(blockName, "layoutType");
      const supports = getCoreFeatures(layoutType) ?? {};

      if (!isEmpty(pick(supports, settingName))) {
        return true;
      }
    }

    return settingValue;
  }
);
