import Accordion from "./accordion-script";

/**
 * Get accordion manager object
 *
 * @returns {Array}
 */
const getAccordionManager = () => {
  if (!window.accordionManager) {
    window.accordionManager = {};
  }

  return window.accordionManager;
};

/**
 * Kick start the accordion
 */
function triggerAccordion({ detail: { selector, previewMode } = {} }) {
  const manager = getAccordionManager();
  if (manager[selector]) {
    manager[selector].dispose();
  }
  if (previewMode === "PREVIEW") {
    let blockElement = document.querySelector(selector);
    if (!blockElement) {
      const editorCanvas = document.querySelector(
        'iframe[name="editor-canvas"]'
      );
      if (editorCanvas) {
        blockElement = editorCanvas.contentWindow.document.querySelector(
          selector
        );
      }
    }
    if (blockElement) {
      manager[selector] = new Accordion(blockElement);
    }
  }
}
window.addEventListener(
  "boldblocks.accordion.settingsUpdated",
  triggerAccordion
);

function removeAccordion({ detail: { selector } = {} }) {
  let blockElement = document.querySelector(selector);
  if (!blockElement) {
    const editorCanvas = document.querySelector('iframe[name="editor-canvas"]');
    if (editorCanvas) {
      blockElement = editorCanvas.contentWindow.document.querySelector(
        selector
      );
    }
  }
  if (blockElement) {
    const manager = getAccordionManager();
    if (manager[selector]) {
      manager[selector].dispose();
    }
  }
}
window.addEventListener("boldblocks.accordion.removePreview", removeAccordion);
