import { getCarouselManager, getThumbsCarousel } from "./utils-for-frontend";
import CarouselScript from "./carousel-script";

function getCarouselElement({ selector, blockName }) {
  let blockElement = document.querySelector(selector);
  if (!blockElement) {
    const editorCanvas = document.querySelector('iframe[name="editor-canvas"]');
    if (editorCanvas) {
      blockElement = editorCanvas.contentWindow.document.querySelector(
        selector
      );
    }
  }
  if (blockElement) {
    if (blockName === "core/post-template") {
      blockElement = blockElement.closest(".wp-block-query");
    }
  }

  return blockElement;
}

function removePreviewCarousel(slider) {
  if (slider) {
    slider.dispose();
  }
}

/**
 * Kick start the carousel on the editor
 */
function triggerCarousel({ detail = {} }) {
  const editorCanvas = document.querySelector('iframe[name="editor-canvas"]');
  if (editorCanvas) {
    if (editorCanvas.contentWindow.document.readyState === "complete") {
      if (detail?.isMount) {
        setTimeout(() => {
          buildPreviewCarousel(detail);
        }, 0);
      } else {
        buildPreviewCarousel(detail);
      }
    } else {
      editorCanvas.addEventListener("load", () => {
        buildPreviewCarousel(detail);
      });
    }
  } else {
    if (detail?.isMount) {
      setTimeout(() => {
        buildPreviewCarousel(detail);
      }, 100);
    } else {
      buildPreviewCarousel(detail);
    }
  }
}
window.addEventListener("boldblocks.carousel.settingsUpdated", triggerCarousel);

function buildPreviewCarousel({
  blockName,
  selector,
  carouselSettings,
  previewMode,
  clickHandler,
}) {
  let blockElement = getCarouselElement({ selector, blockName });
  if (blockElement) {
    const manager = getCarouselManager();
    removePreviewCarousel(manager[selector]);
    if (previewMode === "PREVIEW") {
      if (blockElement?.dataset?.previewMode !== "PREVIEW") {
        blockElement.setAttribute("data-preview-mode", "PREVIEW");
      }
      let carouselElement = blockElement.cloneNode(true);
      carouselElement.addEventListener("click", clickHandler);
      const editBlocks = carouselElement.querySelectorAll("[contenteditable]");
      if (editBlocks) {
        editBlocks.forEach((block) => block.removeAttribute("contenteditable"));
      }
      blockElement.insertAdjacentElement("afterend", carouselElement);

      const args = {
        sliderOptions: { ...carouselSettings },
        instanceSelector: selector,
        sliderOptions: {
          thumbs: getThumbsCarousel(carouselElement, manager),
        },
      };

      if (carouselElement.classList.contains("wp-block-query")) {
        args["wrapperSelector"] = "ul";
        args["itemSelector"] = "li";
        if (blockName === "core/post-template") {
          args["datasetSelector"] = "ul";
        }
      }

      manager[selector] = new CarouselScript(carouselElement, args);
    }
  }
}

function removeCarousel({ detail: { blockName, selector } = {} }) {
  let blockElement = getCarouselElement({ selector, blockName });

  if (blockElement) {
    const manager = getCarouselManager();
    removePreviewCarousel(manager[selector]);
    if (blockElement?.dataset?.previewMode === "PREVIEW") {
      blockElement.setAttribute("data-preview-mode", "EDIT");
    }
  }
}
window.addEventListener("boldblocks.carousel.removePreview", removeCarousel);
