/**
 * External dependencies
 */
import classnames from "classnames";

/**
 * WordPress dependencies
 */
import { __ } from "@wordpress/i18n";
import { addFilter } from "@wordpress/hooks";
import { createHigherOrderComponent } from "@wordpress/compose";

/**
 * Internal dependencies
 */
import { boldblocksHasSupport, refineCustomCSS } from "../../utils";

/**
 * Define feature name
 */
const featureName = "customCSS";

/**
 * Override the default block list element to add custom styles.
 *
 * @param  {Function} BlockListBlock Original component
 * @return {Function}                Wrapped component
 */
export const withCustomStyles = createHigherOrderComponent(
  (BlockListBlock) => (props) => {
    if (!boldblocksHasSupport(props.name, featureName)) {
      return <BlockListBlock {...props} />;
    }

    const {
      attributes: { boldblocks: { customCSS: { value = "" } = {} } = {} },
      clientId,
    } = props;

    const selector = `b-${clientId}`;
    let style;
    if (value) {
      style = refineCustomCSS(value, { selector: `.${selector}` });
    }

    return (
      <>
        <BlockListBlock
          {...props}
          className={classnames(props?.className, {
            [selector]: style,
          })}
        />
        {style && <style>{style}</style>}
      </>
    );
  }
);
addFilter(
  "editor.BlockListBlock",
  `boldblocks/${featureName}/withCustomStyles`,
  withCustomStyles
);
