/**
 * External dependencies
 */
import styled from "@emotion/styled";

/**
 * WordPress dependencies
 */
import { __ } from "@wordpress/i18n";
import { ExternalLink, Spinner } from "@wordpress/components";
import { addQueryArgs } from "@wordpress/url";
import { useContext } from "@wordpress/element";

/**
 * Internal dependencies
 */
import { Section, Widget } from "sdk/components";
import { DataContext } from "../data";

/*
 $break-huge: 1440px;
 $break-wide: 1280px;
 $break-xlarge: 1080px;
 $break-large: 960px;	// admin sidebar auto folds
 $break-medium: 782px;	// adminbar goes big
 $break-small: 600px;
 $break-mobile: 480px;
 $break-zoomed-in: 280px;
*/

const WidgetStyled = styled(Widget)`
  border-top: 0;

  h1 {
    padding: 0;
    margin: 10px 0;
    font-size: 2.5em;
  }

  .welcome {
    &__description {
      ul,
      p {
        font-size: 1.2em;
      }

      ul {
        padding-left: 20px;
        list-style: disc;
      }
    }
  }

  .video-tutorials {
    display: grid;
    grid-template-columns: minmax(0, 1fr);
    gap: 12px;

    @media (min-width: 782px) {
      // $break-medium
      grid-template-columns: repeat(2, minmax(0, 1fr));
    }

    @media (min-width: 1280px) {
      // $break-wide
      grid-template-columns: repeat(3, minmax(0, 1fr));
    }

    &__item {
      border: 1px solid #ddd;

      &__video {
        position: relative;
        width: 100%;
        height: 0;
        padding-bottom: 56.25%;
        margin: 0;

        iframe {
          position: absolute;
          top: 0;
          left: 0;
          width: 100%;
          height: 100%;
        }
      }

      &__desc {
        padding: 8px 10px 10px;
        font-size: 1.2em;
        font-weight: 500;
      }
    }
  }

  h2.view-playlists {
    margin-top: 1rem;
  }
`;

const WelcomeWidget = () => {
  const { Docs: { loading, docs } = {} } = useContext(DataContext);

  return (
    <WidgetStyled
      isHeaderHidden={true}
      isFullRow={true}
      className="welcome-widget welcome"
    >
      <h1>
        {__("Welcome to Content Blocks Builder", "content-blocks-builder")}
      </h1>
      <div className="welcome__description">
        <p>
          {__(
            "Content Blocks Builder (CBB) power-up the default Gutenberg Block Editor to help the process of creating sites with the new WordPress much easier and more enjoyable.",
            "content-blocks-builder"
          )}
        </p>
        <hr />
        <p>
          {__(
            "Thank you for choosing Content Blocks Builder (CBB) for your website. If this is your first time with CBB, we recommend learning about it first by visiting the promotion site or watching the video tutorials below.",
            "content-blocks-builder"
          )}
        </p>
        <h2>
          {__(
            "Here is a list of starting points for you to get started creating with it.",
            "content-blocks-builder"
          )}
        </h2>
        <ul>
          <li>
            {__("Manage custom blocks: ", "content-blocks-builder")}
            <ExternalLink
              href={addQueryArgs("edit.php?post_type=boldblocks_block")}
            >
              {__("All custom blocks", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink
              href={addQueryArgs("post-new.php?post_type=boldblocks_block")}
            >
              {__("Create new block", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink
              href={addQueryArgs(
                "edit.php?post_type=boldblocks_block&page=cbb-block-library"
              )}
            >
              {__("Block Library", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/mICLfKkF6tU">
              {__("Learn to create a grid block", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/WgHuo6jwyN8">
              {__(
                "Create blocks from an external script",
                "content-blocks-builder"
              )}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://www.youtube.com/playlist?list=PLPuEwc7dZklcFBm-hwtNGJmuB-J8nV-fD">
              {__("View all playlist", "content-blocks-builder")}
            </ExternalLink>
          </li>
          <li>
            {__("Manage custom variations: ", "content-blocks-builder")}
            <ExternalLink
              href={addQueryArgs("edit.php?post_type=boldblocks_variation")}
            >
              {__("All custom variations", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink
              href={addQueryArgs(
                "edit.php?post_type=boldblocks_block&page=cbb-variation-library"
              )}
            >
              {__("Variation Library", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/caiY-YZT7ZY">
              {__("Learn to create a variation", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/YQHrf4xFctg">
              {__(
                "Create a variation for the Query Loop block",
                "content-blocks-builder"
              )}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/BAY8_evbyL0">
              {__("Learn to use variation library", "content-blocks-builder")}
            </ExternalLink>
          </li>
          <li>
            {__("Manage custom patterns: ", "content-blocks-builder")}
            <ExternalLink
              href={addQueryArgs("edit.php?post_type=boldblocks_pattern")}
            >
              {__("All patterns", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink
              href={addQueryArgs("post-new.php?post_type=boldblocks_pattern")}
            >
              {__("Create new pattern", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/gfSNwcAb-xc">
              {__("Learn to create a pattern", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/BVvImhhZma4">
              {__(
                "Learn to create a realworld pattern",
                "content-blocks-builder"
              )}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/UTrZSBvkzj0">
              {__(
                "Learn to use the pattern inserter popup",
                "content-blocks-builder"
              )}
            </ExternalLink>
          </li>
          <li>
            {__("Carousel layouts: ", "content-blocks-builder")}
            <ExternalLink href="https://youtu.be/Eh3kX-9_mDg">
              {__("Learn to create a banner slider", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/bcK_k3IfW8g">
              {__(
                "Learn to create a banner slider using Query Loop block",
                "content-blocks-builder"
              )}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://www.youtube.com/playlist?list=PLPuEwc7dZkleS_5ATLat8arnVUflXSfTk">
              {__("View all playlist", "content-blocks-builder")}
            </ExternalLink>
          </li>
          <li>
            {__("Grid layouts: ", "content-blocks-builder")}
            <ExternalLink href="https://youtu.be/awSC09tTnS8">
              {__(
                "Learn to create a responsive grid",
                "content-blocks-builder"
              )}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://www.youtube.com/playlist?list=PLPuEwc7dZklfsbrRAKe_iUywkjk0fPMUE">
              {__("View all playlist", "content-blocks-builder")}
            </ExternalLink>
          </li>
          <li>
            {__("Accordion layout: ", "content-blocks-builder")}
            <ExternalLink href="https://youtu.be/YA4-duNF_w4">
              {__(
                "Learn to create an accordion layout",
                "content-blocks-builder"
              )}
            </ExternalLink>
          </li>
          <li>
            {__("Customize Query Loop: ", "content-blocks-builder")}
            <ExternalLink href="https://youtu.be/aHy3spQVBGc">
              {__(
                "Learn to create a blog page with CBB",
                "content-blocks-builder"
              )}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/YQHrf4xFctg">
              {__(
                "Learn to create blog layouts with overlay style",
                "content-blocks-builder"
              )}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://www.youtube.com/playlist?list=PLPuEwc7dZklchm8nVUOKqSOc6OgmRQyha">
              {__("View all playlist", "content-blocks-builder")}
            </ExternalLink>
          </li>
          <li>
            {__("Background effects: ", "content-blocks-builder")}
            <ExternalLink href="https://youtu.be/nDpeQbpu50s">
              {__("Parallax effect", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/mBleA20caGo">
              {__("Infinite scrolling effect", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/0g1SLTq-lQ4">
              {__("A realworld use case", "content-blocks-builder")}
            </ExternalLink>
          </li>
          <li>
            {__(
              "Modal, off-canvas, toggle layouts: ",
              "content-blocks-builder"
            )}
            <ExternalLink href="https://youtu.be/y31TAKHZOD0">
              {__("Step by step guide", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/52jD9eeBJ78">
              {__("A video popup", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/YnUt-zQXnCU">
              {__("Off-canvas content", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/UEh_Da9Sozs">
              {__("A cookies popup", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/g_KOCqvU0Ps">
              {__("A notification bar", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/E4usfCydR7U">
              {__(
                "A responsive header with hamburger menu, search bar toggle",
                "content-blocks-builder"
              )}
            </ExternalLink>
          </li>
          <li>
            {__("Load Google Fonts for your site: ", "content-blocks-builder")}
            <ExternalLink
              href={addQueryArgs(
                "edit.php?post_type=boldblocks_block&page=cbb-settings&tab=typography"
              )}
            >
              {__("Setup Google Fonts", "content-blocks-builder")}
            </ExternalLink>
            {", "}
            <ExternalLink href="https://youtu.be/rhd4SEKUcHU">
              {__("Learn to load google fonts", "content-blocks-builder")}
            </ExternalLink>
          </li>
          <li>
            {__(
              "Import/export data from/to other sites: ",
              "content-blocks-builder"
            )}
            <ExternalLink
              href={addQueryArgs(
                "edit.php?post_type=boldblocks_block&page=cbb-settings&tab=tools"
              )}
            >
              {__("Import/export Tools", "content-blocks-builder")}
            </ExternalLink>
          </li>
          <li>
            {__("Learn more about CBB: ", "content-blocks-builder")}
            <ExternalLink href="https://contentblocksbuilder.com/?utm_source=Learn+more+CBB&utm_campaign=CBB+visit+site&utm_medium=link&utm_content=setting+description">
              contentblocksbuilder.com
            </ExternalLink>
          </li>
        </ul>
        <h2>{__("How to - video tutorials", "content-blocks-builder")}</h2>
        <p>
          {__(
            "Below is a list of short 'how to' video tutorials, you can use them as learning resources besides the documentation. More videos will be made soon, so, please subscribe to our youtube channel and get notifications when we release new videos. ",
            "content-blocks-builder"
          )}
          <ExternalLink href="https://www.youtube.com/channel/UCB7Y3mlCEKHVM-RCZaTkR1g?sub_confirmation=1">
            Subscribe
          </ExternalLink>
          {", "}
          <ExternalLink href="https://www.youtube.com/channel/UCB7Y3mlCEKHVM-RCZaTkR1g">
            {__("View all videos", "content-blocks-builder")}
          </ExternalLink>
        </p>
        <div className="video-tutorials">
          {loading ? (
            <Spinner />
          ) : (
            docs?.videoTutorials.map(({ title, id }) => (
              <div className="video-tutorials__item" key={id}>
                <div className="video-tutorials__item__video">
                  <iframe
                    src={`https://www.youtube.com/embed/${id}`}
                    srcDoc={`<style>*{padding:0;margin:0;overflow:hidden}html,body{height:100%}img{position:absolute;width:100%;top:0;bottom:0;margin:auto}.btn-play{position: absolute;top: 50%;left: 50%;z-index: 1;display: block;width: 68px;height: 48px;margin:0;cursor: pointer;transform: translate3d(-50%, -50%, 0);background-color: transparent;background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 68 48"><path d="M66.52 7.74c-.78-2.93-2.49-5.41-5.42-6.19C55.79.13 34 0 34 0S12.21.13 6.9 1.55c-2.93.78-4.63 3.26-5.42 6.19C.06 13.05 0 24 0 24s.06 10.95 1.48 16.26c.78 2.93 2.49 5.41 5.42 6.19C12.21 47.87 34 48 34 48s21.79-.13 27.1-1.55c2.93-.78 4.64-3.26 5.42-6.19C67.94 34.95 68 24 68 24s-.06-10.95-1.48-16.26z" fill="red"/><path d="M45 24 27 14v20" fill="white"/></svg>');filter: grayscale(100%);transition: filter .1s cubic-bezier(0, 0, 0.2, 1);border: none;}body:hover .btn-play,.btn-play:focus{filter:none}.visually-hidden{clip: rect(0 0 0 0);clip-path: inset(50%);height: 1px;overflow: hidden;position: absolute;white-space: nowrap;width: 1px;}</style><a href="https://www.youtube.com/embed/${id}?autoplay=1&enablejsapi=1&playsinline=1"><img src="https://img.youtube.com/vi/${id}/hqdefault.jpg" alt="${title}"><button type="button" class="btn-play"><span class="visually-hidden">Play</span></button></a>`}
                    title="YouTube video player"
                    allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
                    allowFullScreen
                  ></iframe>
                </div>
                <div className="video-tutorials__item__desc">{title}</div>
              </div>
            ))
          )}
        </div>
        {docs && docs.playlists && (
          <>
            <h2 className="view-playlists">
              {__("View by playlists", "content-blocks-builder")}
            </h2>
            <ul>
              {docs.playlists.map(({ title, url }) => (
                <li key={url}>
                  <ExternalLink href={url}>{title}</ExternalLink>
                </li>
              ))}
            </ul>
          </>
        )}
      </div>
    </WidgetStyled>
  );
};

const GettingStarted = () => {
  return (
    <Section>
      <WelcomeWidget />
    </Section>
  );
};

export default GettingStarted;
