/**
 * External dependencies
 */

/**
 * WordPress dependencies
 */
import { createReduxStore, register, combineReducers } from "@wordpress/data";
import { controls } from "@wordpress/data-controls";

/**
 * Internal dependencies
 */
import {
  previewModesActions,
  previewModesSelectors,
  previewModesReducer,
} from "./preview-modes";

import {
  patternInserterActions,
  patternInserterSelectors,
  patternInserterResolvers,
  patternInserterReducer,
} from "./pattern-inserter";

import {
  typographyActions,
  typographySelectors,
  typographyResolvers,
  typographyReducer,
  postTypographyReducer,
} from "./typography";

/**
 * Icon library store
 */
import "./icon-library";

/**
 * Constants
 */
const storeName = "boldblocks/data";

/**
 * Register store
 */
export const store = createReduxStore(storeName, {
  selectors: {
    ...typographySelectors,
    ...patternInserterSelectors,
    ...previewModesSelectors,
  },
  actions: {
    ...typographyActions,
    ...patternInserterActions,
    ...previewModesActions,
  },
  controls,
  reducer: combineReducers({
    previewModes: previewModesReducer,
    typography: typographyReducer,
    postTypography: postTypographyReducer,
    patternInserter: patternInserterReducer,
  }),
  resolvers: {
    ...typographyResolvers,
    ...patternInserterResolvers,
  },
});

register(store);

// export { storeName as store };
