/**
 * External dependencies
 */

/**
 * WordPress dependencies
 */
import { __ } from "@wordpress/i18n";
import { useSelect, subscribe } from "@wordpress/data";
import { registerPlugin } from "@wordpress/plugins";
import { useRef, render } from "@wordpress/element";
import { store as editorStore } from "@wordpress/editor";
import { store as blockEditorStore } from "@wordpress/block-editor";
import { Button } from "@wordpress/components";

/**
 * Internal dependencies
 */
import { ReactComponent as BoldBlocksIcon } from "../assets/icon.svg";
import { TemplatesModal } from "../components/template-modal";
import {
  getPatternInserterModalStatus,
  getSetPatternInserterModalStatus,
} from "../utils";
import { SearchParams } from "../utils/searchparams";

/**
 * Register the block templates.
 */
registerPlugin("boldblocks-block-templates", {
  render: () => {
    const { getCurrentPostType, isCleanNewPost } = useSelect(
      (select) => select(editorStore),
      []
    );
    const { getBlockCount } = useSelect(
      (select) => select(blockEditorStore),
      []
    );

    const modalStatus = getPatternInserterModalStatus();
    const setPatternInserterModalStatus = getSetPatternInserterModalStatus();

    // Don't display on block, variation content type
    if (
      ["boldblocks_block", "boldblocks_variation"].indexOf(
        getCurrentPostType()
      ) !== -1
    ) {
      return null;
    }

    const searchParams = new SearchParams();
    if (searchParams.get("bb-template-modal")) {
      setPatternInserterModalStatus(true);
      searchParams.delete("bb-template-modal");
    }

    (() => {
      const hasButton = useRef(false);

      // Create the insert template button
      const buildTemplateInserterButton = subscribe(() => {
        if (hasButton.current) {
          return;
        }

        if (!(isCleanNewPost() || getBlockCount() > 0)) {
          return;
        }

        requestAnimationFrame(() => {
          const postHeader = document.querySelector(
            ".edit-post-header__toolbar"
          );

          if (!postHeader) {
            return;
          }

          let templateInserterElement = document.getElementById(
            "boldblocks-templates-inserter"
          );

          if (templateInserterElement) {
            return;
          }

          templateInserterElement = Object.assign(
            document.createElement("div"),
            {
              id: "boldblocks-templates-inserter",
            }
          );

          const mainToolbar = postHeader.querySelector(
            ".edit-post-header-toolbar"
          );
          if (mainToolbar) {
            mainToolbar.after(templateInserterElement);
          } else {
            postHeader.append(templateInserterElement);
          }
          postHeader.classList.add("has-bb-pattern-button");

          render(
            <>
              <Button
                variant="primary"
                className="button-insert-template"
                icon={BoldBlocksIcon}
                onClick={() => {
                  setPatternInserterModalStatus(true);
                }}
              >
                <span className="button-insert-template__text">
                  {__("Add pattern", "content-blocks-builder")}
                </span>
              </Button>
            </>,
            templateInserterElement
          );

          hasButton.current = true;
        });

        buildTemplateInserterButton();
      });
    })();

    return (
      <>
        {!!modalStatus && (
          <TemplatesModal
            isModalOpen={modalStatus}
            setIsModalOpen={setPatternInserterModalStatus}
          />
        )}
      </>
    );
  },
});
