/**
 * External dependencies
 */

/**
 * WordPress dependencies
 */
import { useDispatch, useSelect } from "@wordpress/data";

/**
 * Internal dependencies
 */
import { store as boldblocksDataStore } from "../store";

/**
 * Get preview mode
 *
 * @param {String} clientId
 * @returns {String}
 */
export function getPreviewMode(clientId) {
  return useSelect(
    (select) => select(boldblocksDataStore).getPreviewMode(clientId),
    []
  );
}

/**
 * The hook to get the setter for the previewMode
 *
 * @returns {Function}
 */
export const useSetPreviewMode = () => {
  const { setPreviewMode } = useDispatch(boldblocksDataStore);

  return setPreviewMode;
};

/**
 * Get templates modal status
 *
 * @returns {String}
 */
export function getPatternInserterModalStatus() {
  return useSelect(
    (select) => select(boldblocksDataStore).getPatternInserterModalStatus(),
    []
  );
}

/**
 * Set templates modal status
 */
export function getSetPatternInserterModalStatus() {
  const { setPatternInserterModalStatus } = useDispatch(boldblocksDataStore);

  return setPatternInserterModalStatus;
}

export const getPatternData = (selector, args) => {
  const { [selector]: getData } = useSelect(
    (select) => select(boldblocksDataStore),
    []
  );

  return getData(args);
};

export const getIsResolving = (
  selector,
  args = [],
  store = boldblocksDataStore
) => {
  return useSelect((select) => select(store).isResolving(selector, args), []);
};

export const getHasFinishedResolution = (
  selector,
  args = [],
  store = boldblocksDataStore
) => {
  return useSelect(
    (select) => select(store).hasFinishedResolution(selector, args),
    []
  );
};
